@@ -153,15 +153,19 @@ def plot_classifier(classifier, x, y):
     :param y: 标签
     :return: None
     '''
-    x, y = check_data_target(x, y)
+    if x.shape[1] > 2:
+        x = PCA(2).fit_transform(x)
     x1_min, x1_max = np.min(x[:, 0]) - 1, np.max(x[:, 0]) + 1
     x2_min, x2_max = np.min(x[:, 1]) - 1, np.max(x[:, 1]) + 1
     step_size = 0.01
     x1_values, x2_values = np.meshgrid(np.arange(x1_min, x1_max, step_size), np.arange(x2_min, x2_max, step_size))
+    classifier.fit(x, y)
     mesh_output = classifier.predict(np.c_[x1_values.ravel(), x2_values.ravel()])
     mesh_output = mesh_output.reshape(x1_values.shape)
     plt.figure()
-    plt.pcolormesh(x1_values, x2_values, mesh_output, cmap=plt.cm.gray)
+    plt.plot(x[y == 0][:, 0], x[y == 0][:, 1], 'bs')
+    plt.plot(x[y == 1][:, 0], x[y == 1][:, 1], 'g^')
+    plt.pcolormesh(x1_values, x2_values, mesh_output, cmap=plt.cm.Paired)
     plt.scatter(x[:, 0], x[:, 1], c=y, s=80, linewidths=1, cmap=plt.cm.Paired)
     plt.xlim(x1_values.min(), x1_values.max())
     plt.ylim(x2_values.min(), x2_values.max())
@@ -170,6 +174,24 @@ def plot_classifier(classifier, x, y):
     plt.show()
 
 
+# def plot_classifier(classifier, x, y, axes=[-1.5, 2.5, -1, 1.5]):
+#     if x.shape[1]>2:
+#         x = PCA(2).fit_transform(x)
+#     classifier.fit(x, y)
+#     plt.plot(x[y == 0][:, 0], x[y == 0][:, 1], 'bs')
+#     plt.plot(x[y == 1][:, 0], x[y == 1][:, 1], 'g^')
+#     plt.grid()
+#     plt.axis(axes)
+#     x0s = np.linspace(axes[0], axes[1], 200)
+#     x1s = np.linspace(axes[2], axes[3], 200)
+#     x0, x1 = np.meshgrid(x0s, x1s)
+#     x = np.c_[x0.ravel(), x1.ravel()]
+#     y_pred = classifier.predict(x)
+#     y_pred = y_pred.reshape(x0.shape)
+#     plt.contourf(x0, x1, y_pred, cmap=plt.cm.brg, alpha=0.2)
+#     plt.show()
+
+
 # 检查数据和标签的形状
 def check_data_target(x, y):
     '''
